@@ -20,6 +20,11 @@ class SituacoesDePagamento(object):
         return getattr(cls, tipo, None)
 
 
+class Topicos(object):
+    pagamento = "payment"
+    ordem_pagamento = "merchant_order"
+
+
 class Registro(RegistroBase):
     def __init__(self, dados, tipo="retorno", configuracao=None):
         super(Registro, self).__init__(dados, configuracao)
@@ -30,7 +35,10 @@ class Registro(RegistroBase):
 
     @property
     def url(self):
-        return "https://api.mercadolibre.com/collections/notifications/{}".format(self.dados["id"])
+        if self.topico == Topicos.pagamento:
+            return "https://api.mercadolibre.com/collections/notifications/{}".format(self.dados["id"])
+        if self.topico == Topicos.ordem_pagamento:
+            return self.dados.get("resource", "https://api.mercadolibre.com/merchant_orders/{}".format(self.dados["id"]))
 
     @property
     def pedido_numero(self):
@@ -56,7 +64,7 @@ class Registro(RegistroBase):
                     return False
                 return self.dados["collection_status"] == SituacoesDePagamento.do_tipo(tipo)
             if self.retorno_de_notificacao:
-                return self.dados["collection"]["status"] == SituacoesDePagamento.do_tipo(tipo)
+                return self.item_topico["status"] == SituacoesDePagamento.do_tipo(tipo)
         return object.__getattribute__(self, name)
 
     @property
@@ -87,11 +95,31 @@ class Registro(RegistroBase):
 
     @property
     def retorno_de_notificacao(self):
-        return "collection" in self.dados
+        return self.chave_topico in self.dados
 
     @property
     def obter_dados_do_gateway(self):
-        return "topic" in self.dados and self.dados["topic"] == "payment"
+        return self.topico is not None
+
+    @property
+    def chave_topico(self):
+        if self.topico == Topicos.pagamento:
+            return "collection"
+        if self.topico == Topicos.ordem_pagamento:
+            return "payments"
+
+    @property
+    def item_topico(self):
+        if self.topico == Topicos.pagamento:
+            return self.dados[self.chave_topico]
+        if self.topico == Topicos.ordem_pagamento:
+            return self.dados[self.chave_topico][0]
+
+    @property
+    def topico(self):
+        if "topic" in self.dados:
+            return self.dados["topic"]
+        return None
 
     @property
     def redireciona_para(self):
