@@ -6,7 +6,7 @@ from datetime import timedelta, datetime
 import requests
 from pagador.seguranca import autenticador
 from pagador.seguranca.autenticador import TipoAutenticacao
-from pagador.seguranca.instalacao import Parametros, InstalacaoNaoFinalizada
+from pagador.seguranca.instalacao import Parametros, InstalacaoNaoFinalizada, InstaladorBase
 from pagador.settings import MERCADOPAGO_REDIRECT_URL
 import pagador_mercadopago
 
@@ -46,10 +46,11 @@ class Credenciador(autenticador.Credenciador):
         return datetime.now() > self.token_expiracao
 
 
-class Instalador(object):
+class Instalador(InstaladorBase):
     campos = ["usuario", "token", "token_expiracao", "codigo_autorizacao"]
 
-    def __init__(self, **filtro_parametros):
+    def __init__(self, configuracao, **filtro_parametros):
+        super(Instalador, self).__init__(configuracao)
         self.conta_id = filtro_parametros["id"]
         self.parametros = ParametrosMercadoPago("mercadopago", **filtro_parametros)
 
